Question class

Constructors

Question({required String text, required List<String> options, required int correctIndex})

Properties

correctIndex → int
final
hashCode → int
The hash code for this object.
no setterinherited
options → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited